@@ -73,20 +73,24 @@ def beginUndoGroup():
 
     """
     try:
-        client.call("ak.wwise.core.undo.beginGroup")
+        res = client.call("ak.wwise.core.undo.beginGroup")
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 def cancelUndoGroup():
     """Cancel an undo group
 
         """
     try:
-        client.call("ak.wwise.core.undo.cancelGroup")
+        res = client.call("ak.wwise.core.undo.cancelGroup")
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 def endUndoGroup(undogroup):
     """Name and end an undo group
@@ -96,20 +100,24 @@ def endUndoGroup(undogroup):
     """
     undoArgs = {"displayName": undogroup}
     try:
-        client.call("ak.wwise.core.undo.endGroup", undoArgs)
+        res = client.call("ak.wwise.core.undo.endGroup", undoArgs)
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 def saveWwiseProject():
     """Save the wwise project
 
     """
     try:
-        client.call("ak.wwise.core.project.save")
+        res = client.call("ak.wwise.core.project.save")
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 def setupSubscription(subscription, target, returnArgs = ["id", "name", "path"]):
     """Subscribe to an event. Define a target to call when triggered, get the retunArgs back
@@ -120,19 +128,24 @@ def setupSubscription(subscription, target, returnArgs = ["id", "name", "path"])
 
     """
     try:
-        client.subscribe(subscription, target, {"return": returnArgs})
+        res = client.subscribe(subscription, target, {"return": returnArgs})
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
-def getProjectInfo(ret=[]):
+def getProjectInfo(additionalProperties=[]):
     """Get the wwise project info by default returns filePath, @DefaultLanguage
 
+    :param additionalProperties: List of additional properties to return from the project (optional)
+    :return: Results structure or False
+
     """
     arguments = {
         "from": {"ofType": ["Project"]},
         "options": {
-            "return": ["type","id", "name", "filePath","@DefaultLanguage"]+ret
+            "return": ["type","id", "name", "filePath","@DefaultLanguage"]+additionalProperties
         }
     }
     try:
@@ -146,6 +159,8 @@ def getProjectInfo(ret=[]):
 def getLanguages():
     """Get the list of languages from the wwise project
 
+    :return: List of languages
+
     """
     langlist=[]
     arguments = {
@@ -160,7 +175,7 @@ def getLanguages():
         print("call error: {}".format(ex))
         return False
     else:
-        for lang in res.kwresults["return"]:
+        for lang in res["return"]:
             if lang['name'] != 'SFX' and lang['name'] != 'External' and lang['name'] != 'Mixed':
                 langlist.append(lang['name'])
         return langlist
@@ -168,6 +183,8 @@ def getLanguages():
 def getPathToWwiseProjectFolder():
     """Gets a path to the root folder of wwise project, cleans any nonsense from Mac paths.
 
+    :return: os.path formated path to the wwise folder on disk
+
     """
     projectInfo = getProjectInfo()
     WwiseProjectPath = projectInfo["filePath"]
@@ -304,7 +321,7 @@ def setupImportArgs(parentID, fileList,originalsPath,language="SFX"):
     :param fileList: List of audio files to import
     :param originalsPath: Relative location to put new files inside Originals
     :param language: Import audio as SFX (default) or a given language
-    :return: Result structure or False
+    :return: An arguments structure ready to be passed into importAudioFiles()
 
     """
     ParentID = str(parentID)
@@ -341,18 +358,20 @@ def deleteWwiseObject(object):
     """
     args = {"object":object}
     try:
-        client.call("ak.wwise.core.object.delete",args)
+        res = client.call("ak.wwise.core.object.delete",args)
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 ###  Searching the project  ######
 
 def getSelectedObjects(properties=[]):
-    """Get the currently selected object(s), returning any extra properties
+    """Get the currently selected object(s), returning any extra properties.
+    By default objects will return ["id","type", "name", "path"] + properties[]
 
     :param properties: list of additional properties to be returned for the wwise objects.
-    by default objects will return ["id","type", "name", "path"] + properties[]
     :return: Result structure or False
 
     """
@@ -447,7 +466,9 @@ def getDescendantObjects(fromObject,returnProperties=[],tfrom="id",select="desce
 
 def getObjectsByName(name,type,returnProperties=[],tfrom="ofType"):
     """Perform a search by name, return additional properties for each object.
-    Named search must also include a type filter
+    Named search must also include a type filter.
+    For more info on options see Wwise SDK for ak.wwise.core.object.get
+    https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
 
     :param name: String to match with object names
     :param type: Type of wwise objects to search for
@@ -455,9 +476,6 @@ def getObjectsByName(name,type,returnProperties=[],tfrom="ofType"):
     :param tfrom: Key that determines how fromObject is used in the search (default=ofType)
     :return: Result structure or False
 
-    for more info on options see Wwise SDK for ak.wwise.core.object.get
-    https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
-
     """
     baseProperties = ["id","type", "name", "path"]
     arguments = {
@@ -629,6 +647,7 @@ def getOperator(string):
 #####  Soundbanks #####
 def generateSoundbanks(banklist = []):
     """Generate soundbanks
+
     :param banklist: List of bank names to generate
     """
     args = {
@@ -638,13 +657,16 @@ def generateSoundbanks(banklist = []):
         ]
     }
     try:
-        client.call("ak.wwise.ui.commands.execute", args)
+        res = client.call("ak.wwise.ui.commands.execute", args)
     except Exception as ex:
         print("call error: {}".format(ex))
         return False
+    else:
+        return res
 
 def getSoundbanks(tfrom,obj):
     """ Return all Soundbanks referencing any object of the Work Unit directly
+
     :param tfrom: Key that determines how obj is used in the search (default=id)
     :param obj: The object to use in the search
     :return: List of banks directly referencing obj
@@ -714,21 +736,24 @@ def automationMode(enabled):
 
 def checkoutWorkUnit(workunitID):
     """Source control operation to check out work unit
+
     :param workunitID: GUID of the work unit to checkout
     :return: Result structure or False
     """
     return executeCommand("WorkgroupCheckoutWWU",workunitID)
 
 def cleanfilePathFromWwise(path):
-    """Cleans the undesired characters from Mac paths that Wwise gives you
+    """Cleans the undesired characters from Mac paths that Wwise gives you. E.g. replaces Y: with ~
+
     :param path: path to clean (e.g. wproj or work unit path)
-    :return: Cleaned path
+    :return: os.path formated path, cleaned of Mac/WINE characters
     """
     cleanMacpath = path.replace("Y:","~").replace('\\', '/')
     return os.path.abspath(os.path.expanduser(cleanMacpath))
 
 def setSwitchContainerAssignment(switch,child):
     """Assign a given child object to a given switch (switch container)
+
     :param switch: Name of the switch to assign child to
     :param child: ID of the wwise object to assign to switch
     :return: Result structure or False
@@ -747,6 +772,7 @@ def setSwitchContainerAssignment(switch,child):
 
 def removeSwitchContainerAssignment(switch,child):
     """Remove a given child object from a given switch (switch container)
+
     :param switch: Name of the switch to assign child to
     :param child: ID of the wwise object to assign to switch
     :return: Result structure or False
@@ -765,6 +791,7 @@ def removeSwitchContainerAssignment(switch,child):
 
 def moveWwiseObject(object,parent, conflict="replace"):
     """move object to new location under parent
+
     :param object: ID of wwise object to move
     :param parent: ID of the parent to move object under
     :param conflict: Behaviour for conflicting objects (default = replace)
@@ -785,8 +812,30 @@ def moveWwiseObject(object,parent, conflict="replace"):
     else:
         return res
 
+def renameWwiseObject(object,newName):
+    """Rename a given object with newName
+
+    :param object: ID of wwise object to rename
+    :param newName: The new name of the wwise object
+    :return: Result structure or False
+
+    """
+    args = {
+
+        "object": object,
+        "value": newName
+    }
+    try:
+        res = client.call("ak.wwise.core.object.setName", args)
+    except Exception as ex:
+        print("call error: {}".format(ex))
+        return False
+    else:
+        return res
+
 def copyWwiseObject(object, parent, conflict="replace"):
     """copy object to new location under parent
+    
     :param object: ID of wwise object to copy
     :param parent: ID of the parent to paste object under
     :param conflict: Behaviour for conflicting objects (default = replace)
